%define upstream_name    Test-MemoryGrowth
%define upstream_version 0.04

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Assert that code does not cause growth in memory usage
License:    GPLv1+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://www.cpan.org/modules/by-module/Test/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Module::Build) >= 0.400.400
BuildRequires: perl(Test::Builder)
BuildRequires: perl(Test::Builder::Tester)
BuildRequires: perl(Test::More)
BuildArch:  noarch

%description
This module provides a function to check that a given block of code does
not result in the process consuming extra memory once it has finished.
Despite the name of this module it does not, in the strictest sense of the
word, test for a memory leak: that term is specifically applied to cases
where memory has been allocated but all record of it has been lost, so it
cannot possibly be reclaimed. While the method employed by this module can
detect such bugs, it can also detect cases where memory is still referenced
and reachable, but the usage has grown more than would be expected or
necessary.

The block of code will be run a large number of times (by default 10,000),
and the difference in memory usage by the process before and after is
compared. If the memory usage has now increased by more than one byte per
call, then the test fails.

In order to give the code a chance to load initial resources it needs, it
will be run a few times first (by default 10); giving it a chance to load
files, AUTOLOADs, caches, or any other information that it requires. Any
extra memory usage here will not count against it.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Build.PL --installdirs=vendor

./Build

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Mon Mar 21 2022 umeabot <umeabot> 0.40.0-2.mga9
+ Revision: 1812777
- Mageia 9 Mass Rebuild

* Fri Jun 19 2020 tv <tv> 0.40.0-1.mga8
+ Revision: 1596601
- update to 0.04

* Thu Jun 11 2020 tv <tv> 0.30.0-1.mga8
+ Revision: 1592312
- imported package perl-Test-MemoryGrowth


* Thu Jun 11 2020 Thierry Vignaud <tv@mageia.org> 0.30.0-1.mga8
- initial mageia release, generated with cpan2dist
